@@ -16,24 +16,27 @@ OC.L10N.register(
     "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
     "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
     "Upload cancelled." : "Yükleme iptal edildi.",
+    "Processing files …" : "Dosyalar işleniyor …",
     "…" : "…",
-    "Processing files …" : "Dosyalar işleniyor…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnız {size2} boş alan var",
     "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
     "Not enough free space" : "Yeterli boş alan yok",
     "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
-    "Uploading …" : "Yükleniyor…",
+    "Uploading …" : "Yükleniyor …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
     "Target folder does not exist any more" : "Hedef klasör artık yok",
     "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
     "Actions" : "İşlemler",
-    "Rename" : "Yeniden Adlandır",
+    "Rename" : "Yeniden adlandır",
     "Copy" : "Kopyala",
     "Choose target folder" : "Hedef klasörü seçin",
+    "Open" : "Aç",
+    "Delete file" : "Dosyayı sil",
+    "Delete folder" : "Klasörü sil",
     "Disconnect storage" : "Depolama bağlantısını kes",
-    "Unshare" : "Paylaşımı Kaldır",
+    "Unshare" : "Paylaşımı kaldır",
     "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
     "Files" : "Dosyalar",
     "Details" : "Ayrıntılar",
@@ -44,6 +47,7 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da yönetici ile görüşün",
     "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
     "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
+    "copy" : "kopya",
     "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
     "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
     "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
@@ -64,9 +68,10 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
     "{dirs} and {files}" : "{dirs} ve {files}",
     "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
-    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya ekleme izniniz yok",
+    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
     "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
     "New" : "Yeni",
+    "Select file range" : "Dosya aralığını seçin",
     "{used} of {quota} used" : "{used} / {quota} kullanılmış",
     "{used} used" : "{used} kullanılmış",
     "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
@@ -85,6 +90,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
     "Favorited" : "Sık kullanılanlara eklendi",
     "Favorite" : "Sık kullanılanlara ekle",
+    "You can only favorite a single file or folder at a time" : "Aynı anda yalnız bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
     "New folder" : "Yeni klasör",
     "Upload file" : "Dosya yükle",
     "Not favorited" : "Sık kullanılanlarda değil",
@@ -120,7 +126,7 @@ OC.L10N.register(
     "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
     "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
     "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
-    "You moved {oldfile} to {newfile}" : "{oldfile} dosyası nı{newfile} dosyasına taşıdınız",
+    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
     "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
     "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Bir dosya ya da klasör <strong>değiştirildi</strong> ya da <strong>yeniden adlandırıldı</strong>",
@@ -130,21 +136,20 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Bir dosya ya da klasör <strong>geri yüklendi</strong>",
     "Unlimited" : "Sınırsız",
     "Upload (max. %s)" : "Yükle (en büyük: %s)",
+    "Accept" : "Kabul Et",
     "File Management" : "Dosya Yönetimi",
-    "File handling" : "Dosya işlemleri",
-    "Maximum upload size" : "En büyük yükleme boyutu",
-    "max. possible: " : "olabilecek en büyük:",
-    "Save" : "Kaydet",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM üzerinde değişikliklerin uygulanması 5 dakika sürebilir.",
-    "Missing permissions to edit from here." : "Buradan düzenleme için izinler eksik.",
-    "%1$s of %2$s used" : "%1$s / %2$s kullanıldı",
+    "Invalid path selected" : "Seçilen yol geçersiz",
+    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
+    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
+    "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
     "%s used" : "%s kullanılıyor",
+    "%s%% of %s used" : "%s%%/%s kullanılmış",
+    "%1$s of %2$s used" : "%1$s / %2$s kullanıldı",
     "Settings" : "Ayarlar",
     "Show hidden files" : "Gizli dosyaları görüntüle",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Dosyalarınıza WebDAV üzerinden erişmek için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">bu adresi kullanın</a>",
     "Toggle grid view" : "Tablo görünümünü değiştir",
-    "Cancel upload" : "Yüklemeyi iptal et",
     "No files in here" : "Burada herhangi bir dosya yok",
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
     "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
@@ -158,15 +163,18 @@ OC.L10N.register(
     "Shares" : "Paylaşımlar",
     "Shared with others" : "Diğerleri ile paylaşılan",
     "Shared with you" : "Sizinle paylaşılan",
-    "Shared by link" : "Paylaşım bağlantısı",
+    "Shared by link" : "Bağlantı ile paylaşılmış",
     "Deleted shares" : "Silinmiş paylaşımlar",
     "Text file" : "Metin dosyası",
     "New text file.txt" : "Yeni metin dosyası.txt",
-    "Move" : "Taşı",
-    "Target folder" : "Hedef klasör",
-    "A new file or folder has been <strong>deleted</strong>" : "Yeni bir dosya ya da klasör <strong>silindi</strong>",
-    "A new file or folder has been <strong>restored</strong>" : "Yeni bir dosya ya da klasör <strong>geri yüklendi</strong>",
+    "File handling" : "Dosya işlemleri",
+    "Maximum upload size" : "En büyük yükleme boyutu",
+    "max. possible: " : "olabilecek en büyük:",
+    "Save" : "Kaydet",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM üzerinde değişikliklerin uygulanması 5 dakika sürebilir.",
+    "Missing permissions to edit from here." : "Buradan düzenleme için izinler eksik.",
+    "Cancel upload" : "Yüklemeyi iptal et",
     "%s of %s used" : "%s / %s kullanılıyor",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Dosyalarınıza WebDAV üzerinden erişmek için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">bu adresi kullanın</a>"
+    "%1$s%% of %2$s used" : "%1$s%% / %2$s kullanılmış"
 },
 "nplurals=2; plural=(n > 1);");
