@@ -4,9 +4,12 @@
  *
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Bastien Ho <bastienho@urbancube.fr>
+ * @author Bjoern Schiessle <bjoern@schiessle.org>
  * @author Björn Schießle <bjoern@schiessle.org>
  * @author Florin Peter <github@florin-peter.de>
- * @author Georg Ehrke <georg@owncloud.com>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
+ * @author Joas Schilling <coding@schilljs.com>
+ * @author Juan Pablo Villafáñez <jvillafanez@solidgear.es>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
@@ -15,7 +18,7 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Sjors van der Pluijm <sjors@desjors.nl>
- * @author Stefan Weil <sw@weilnetz.de>
+ * @author Steven Bühner <buehner@me.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
@@ -42,7 +45,10 @@ use OC\Files\Filesystem;
 use OC\Files\View;
 use OCA\Files_Trashbin\AppInfo\Application;
 use OCA\Files_Trashbin\Command\Expire;
+use OCP\Files\File;
+use OCP\Files\Folder;
 use OCP\Files\NotFoundException;
+use OCP\Files\NotPermittedException;
 use OCP\User;
 
 class Trashbin {
@@ -88,8 +94,12 @@ class Trashbin {
 		if (!$userManager->userExists($uid)) {
 			$uid = User::getUser();
 		}
+		if (!$uid) {
+			// no owner, usually because of share link from ext storage
+			return [null, null];
+		}
 		Filesystem::initMountPoints($uid);
-		if ($uid != User::getUser()) {
+		if ($uid !== User::getUser()) {
 			$info = Filesystem::getFileInfo($filename);
 			$ownerView = new View('/' . $uid . '/files');
 			try {
@@ -179,14 +189,19 @@ class Trashbin {
 
 		$target = $user . '/files_trashbin/files/' . $targetFilename . '.d' . $timestamp;
 		$source = $owner . '/files_trashbin/files/' . $sourceFilename . '.d' . $timestamp;
-		self::copy_recursive($source, $target, $view);
+		$free = $view->free_space($target);
+		$isUnknownOrUnlimitedFreeSpace = $free < 0;
+		$isEnoughFreeSpaceLeft = $view->filesize($source) < $free;
+		if ($isUnknownOrUnlimitedFreeSpace || $isEnoughFreeSpaceLeft) {
+			self::copy_recursive($source, $target, $view);
+		}
 
 
 		if ($view->file_exists($target)) {
 			$query = \OC_DB::prepare("INSERT INTO `*PREFIX*files_trash` (`id`,`timestamp`,`location`,`user`) VALUES (?,?,?,?)");
 			$result = $query->execute(array($targetFilename, $timestamp, $targetLocation, $user));
 			if (!$result) {
-				\OCP\Util::writeLog('files_trashbin', 'trash bin database couldn\'t be updated for the files owner', \OCP\Util::ERROR);
+				\OC::$server->getLogger()->error('trash bin database couldn\'t be updated for the files owner', ['app' => 'files_trashbin']);
 			}
 		}
 	}
@@ -196,14 +211,22 @@ class Trashbin {
 	 * move file to the trash bin
 	 *
 	 * @param string $file_path path to the deleted file/directory relative to the files root directory
+	 * @param bool $ownerOnly delete for owner only (if file gets moved out of a shared folder)
+	 *
 	 * @return bool
 	 */
-	public static function move2trash($file_path) {
+	public static function move2trash($file_path, $ownerOnly = false) {
 		// get the user for which the filesystem is setup
 		$root = Filesystem::getRoot();
 		list(, $user) = explode('/', $root);
 		list($owner, $ownerPath) = self::getUidAndFilename($file_path);
 
+		// if no owner found (ex: ext storage + share link), will use the current user's trashbin then
+		if (is_null($owner)) {
+			$owner = $user;
+			$ownerPath = $file_path;
+		}
+
 		$ownerView = new View('/' . $owner);
 		// file has been deleted in between
 		if (is_null($ownerPath) || $ownerPath === '' || !$ownerView->file_exists('/files/' . $ownerPath)) {
@@ -240,11 +263,15 @@ class Trashbin {
 			if ($trashStorage->file_exists($trashInternalPath)) {
 				$trashStorage->unlink($trashInternalPath);
 			}
-			\OCP\Util::writeLog('files_trashbin', 'Couldn\'t move ' . $file_path . ' to the trash bin', \OCP\Util::ERROR);
+			\OC::$server->getLogger()->error('Couldn\'t move ' . $file_path . ' to the trash bin', ['app' => 'files_trashbin']);
 		}
 
 		if ($sourceStorage->file_exists($sourceInternalPath)) { // failed to delete the original file, abort
-			$sourceStorage->unlink($sourceInternalPath);
+			if ($sourceStorage->is_dir($sourceInternalPath)) {
+				$sourceStorage->rmdir($sourceInternalPath);
+			} else {
+				$sourceStorage->unlink($sourceInternalPath);
+			}
 			return false;
 		}
 
@@ -254,15 +281,15 @@ class Trashbin {
 			$query = \OC_DB::prepare("INSERT INTO `*PREFIX*files_trash` (`id`,`timestamp`,`location`,`user`) VALUES (?,?,?,?)");
 			$result = $query->execute(array($filename, $timestamp, $location, $owner));
 			if (!$result) {
-				\OCP\Util::writeLog('files_trashbin', 'trash bin database couldn\'t be updated', \OCP\Util::ERROR);
+				\OC::$server->getLogger()->error('trash bin database couldn\'t be updated', ['app' => 'files_trashbin']);
 			}
 			\OCP\Util::emitHook('\OCA\Files_Trashbin\Trashbin', 'post_moveToTrash', array('filePath' => Filesystem::normalizePath($file_path),
 				'trashPath' => Filesystem::normalizePath($filename . '.d' . $timestamp)));
 
 			self::retainVersions($filename, $owner, $ownerPath, $timestamp);
 
-			// if owner !== user we need to also add a copy to the owners trash
-			if ($user !== $owner) {
+			// if owner !== user we need to also add a copy to the users trash
+			if ($user !== $owner && $ownerOnly === false) {
 				self::copyFilesToUser($ownerPath, $owner, $file_path, $user, $timestamp);
 			}
 		}
@@ -370,7 +397,7 @@ class Trashbin {
 		if ($timestamp) {
 			$location = self::getLocation($user, $filename, $timestamp);
 			if ($location === false) {
-				\OCP\Util::writeLog('files_trashbin', 'trash bin database inconsistent!', \OCP\Util::ERROR);
+				\OC::$server->getLogger()->error('trash bin database inconsistent! ($user: ' . $user . ' $filename: ' . $filename . ', $timestamp: ' . $timestamp . ')', ['app' => 'files_trashbin']);
 			} else {
 				// if location no longer exists, restore file in the root directory
 				if ($location !== '/' &&
@@ -393,6 +420,9 @@ class Trashbin {
 		$mtime = $view->filemtime($source);
 
 		// restore file
+		if (!$view->isCreatable(dirname($target))) {
+			throw new NotPermittedException("Can't restore trash item because the target folder is not writable");
+		}
 		$restoreResult = $view->rename($source, $target);
 
 		// handle the restore result
@@ -469,16 +499,66 @@ class Trashbin {
 	 */
 	public static function deleteAll() {
 		$user = User::getUser();
+		$userRoot = \OC::$server->getUserFolder($user)->getParent();
 		$view = new View('/' . $user);
-		$view->deleteAll('files_trashbin');
+		$fileInfos = $view->getDirectoryContent('files_trashbin/files');
+
+		try {
+			$trash = $userRoot->get('files_trashbin');
+		} catch (NotFoundException $e) {
+			return false;
+		}
+
+		// Array to store the relative path in (after the file is deleted, the view won't be able to relativise the path anymore)
+		$filePaths = array();
+		foreach($fileInfos as $fileInfo){
+			$filePaths[] = $view->getRelativePath($fileInfo->getPath());
+		}
+		unset($fileInfos); // save memory
+
+		// Bulk PreDelete-Hook
+		\OC_Hook::emit('\OCP\Trashbin', 'preDeleteAll', array('paths' => $filePaths));
+
+		// Single-File Hooks
+		foreach($filePaths as $path){
+			self::emitTrashbinPreDelete($path);
+		}
+
+		// actual file deletion
+		$trash->delete();
 		$query = \OC_DB::prepare('DELETE FROM `*PREFIX*files_trash` WHERE `user`=?');
 		$query->execute(array($user));
-		$view->mkdir('files_trashbin');
-		$view->mkdir('files_trashbin/files');
+
+		// Bulk PostDelete-Hook
+		\OC_Hook::emit('\OCP\Trashbin', 'deleteAll', array('paths' => $filePaths));
+
+		// Single-File Hooks
+		foreach($filePaths as $path){
+			self::emitTrashbinPostDelete($path);
+		}
+
+		$trash = $userRoot->newFolder('files_trashbin');
+		$trash->newFolder('files');
 
 		return true;
 	}
 
+	/**
+	 * wrapper function to emit the 'preDelete' hook of \OCP\Trashbin before a file is deleted
+	 * @param string $path
+	 */
+	protected static function emitTrashbinPreDelete($path){
+		\OC_Hook::emit('\OCP\Trashbin', 'preDelete', array('path' => $path));
+	}
+
+	/**
+	 * wrapper function to emit the 'delete' hook of \OCP\Trashbin after a file has been deleted
+	 * @param string $path
+	 */
+	protected static function emitTrashbinPostDelete($path){
+		\OC_Hook::emit('\OCP\Trashbin', 'delete', array('path' => $path));
+	}
+
 	/**
 	 * delete file from trash bin permanently
 	 *
@@ -489,6 +569,7 @@ class Trashbin {
 	 * @return int size of deleted files
 	 */
 	public static function delete($filename, $user, $timestamp = null) {
+		$userRoot = \OC::$server->getUserFolder($user)->getParent();
 		$view = new View('/' . $user);
 		$size = 0;
 
@@ -502,14 +583,21 @@ class Trashbin {
 
 		$size += self::deleteVersions($view, $file, $filename, $timestamp, $user);
 
-		if ($view->is_dir('/files_trashbin/files/' . $file)) {
+		try {
+			$node = $userRoot->get('/files_trashbin/files/' . $file);
+		} catch (NotFoundException $e) {
+			return $size;
+		}
+
+		if ($node instanceof Folder) {
 			$size += self::calculateSize(new View('/' . $user . '/files_trashbin/files/' . $file));
-		} else {
+		} else if ($node instanceof File) {
 			$size += $view->filesize('/files_trashbin/files/' . $file);
 		}
-		\OC_Hook::emit('\OCP\Trashbin', 'preDelete', array('path' => '/files_trashbin/files/' . $file));
-		$view->unlink('/files_trashbin/files/' . $file);
-		\OC_Hook::emit('\OCP\Trashbin', 'delete', array('path' => '/files_trashbin/files/' . $file));
+
+		self::emitTrashbinPreDelete('/files_trashbin/files/' . $file);
+		$node->delete();
+		self::emitTrashbinPostDelete('/files_trashbin/files/' . $file);
 
 		return $size;
 	}
@@ -556,8 +644,6 @@ class Trashbin {
 
 		if ($timestamp) {
 			$filename = $filename . '.d' . $timestamp;
-		} else {
-			$filename = $filename;
 		}
 
 		$target = Filesystem::normalizePath('files_trashbin/files/' . $filename);
@@ -607,7 +693,7 @@ class Trashbin {
 			if(is_null($userFolder)) {
 				return 0;
 			}
-			$free = $quota - $userFolder->getSize(); // remaining free space for user
+			$free = $quota - $userFolder->getSize(false); // remaining free space for user
 			if ($free > 0) {
 				$availableSpace = ($free * self::DEFAULTMAXSIZE / 100) - $trashbinSize; // how much space can be used for versions
 			} else {
@@ -621,7 +707,7 @@ class Trashbin {
 	}
 
 	/**
-	 * resize trash bin if necessary after a new file was added to ownCloud
+	 * resize trash bin if necessary after a new file was added to Nextcloud
 	 *
 	 * @param string $user user id
 	 */
@@ -686,7 +772,7 @@ class Trashbin {
 			foreach ($files as $file) {
 				if ($availableSpace < 0 && $expiration->isExpired($file['mtime'], true)) {
 					$tmp = self::delete($file['name'], $user, $file['mtime']);
-					\OCP\Util::writeLog('files_trashbin', 'remove "' . $file['name'] . '" (' . $tmp . 'B) to meet the limit of trash bin size (50% of available quota)', \OCP\Util::INFO);
+					\OC::$server->getLogger()->info('remove "' . $file['name'] . '" (' . $tmp . 'B) to meet the limit of trash bin size (50% of available quota)', ['app' => 'files_trashbin']);
 					$availableSpace += $tmp;
 					$size += $tmp;
 				} else {
@@ -713,8 +799,12 @@ class Trashbin {
 			$timestamp = $file['mtime'];
 			$filename = $file['name'];
 			if ($expiration->isExpired($timestamp)) {
-				$count++;
-				$size += self::delete($filename, $user, $timestamp);
+				try {
+					$size += self::delete($filename, $user, $timestamp);
+					$count++;
+				} catch (\OCP\Files\NotPermittedException $e) {
+					\OC::$server->getLogger()->logException($e, ['app' => 'files_trashbin', 'level' => \OCP\ILogger::WARN, 'message' => 'Removing "' . $filename . '" from trashbin failed.']);
+				}
 				\OC::$server->getLogger()->info(
 					'Remove "' . $filename . '" from trashbin because it exceeds max retention obligation term.',
 					['app' => 'files_trashbin']
@@ -796,10 +886,10 @@ class Trashbin {
 			foreach ($matches as $ma) {
 				if ($timestamp) {
 					$parts = explode('.v', substr($ma['path'], 0, $offset));
-					$versions[] = (end($parts));
+					$versions[] = end($parts);
 				} else {
 					$parts = explode('.v', $ma);
-					$versions[] = (end($parts));
+					$versions[] = end($parts);
 				}
 			}
 		}
@@ -847,7 +937,7 @@ class Trashbin {
 	 * @return integer size of the folder
 	 */
 	private static function calculateSize($view) {
-		$root = \OC::$server->getConfig()->getSystemValue('datadirectory') . $view->getAbsolutePath('');
+		$root = \OC::$server->getConfig()->getSystemValue('datadirectory', \OC::$SERVERROOT . '/data') . $view->getAbsolutePath('');
 		if (!file_exists($root)) {
 			return 0;
 		}
@@ -895,8 +985,6 @@ class Trashbin {
 		\OCP\Util::connectHook('OC_Filesystem', 'post_write', 'OCA\Files_Trashbin\Hooks', 'post_write_hook');
 		// pre and post-rename, disable trash logic for the copy+unlink case
 		\OCP\Util::connectHook('OC_Filesystem', 'delete', 'OCA\Files_Trashbin\Trashbin', 'ensureFileScannedHook');
-		\OCP\Util::connectHook('OC_Filesystem', 'rename', 'OCA\Files_Trashbin\Storage', 'preRenameHook');
-		\OCP\Util::connectHook('OC_Filesystem', 'post_rename', 'OCA\Files_Trashbin\Storage', 'postRenameHook');
 	}
 
 	/**
@@ -923,6 +1011,6 @@ class Trashbin {
 	 * @return string
 	 */
 	public static function preview_icon($path) {
-		return \OCP\Util::linkToRoute('core_ajax_trashbin_preview', array('x' => 32, 'y' => 32, 'file' => $path));
+		return \OC::$server->getURLGenerator()->linkToRoute('core_ajax_trashbin_preview', array('x' => 32, 'y' => 32, 'file' => $path));
 	}
 }
