@@ -8,6 +8,8 @@ OC.L10N.register(
     "Name cannot be empty" : "Name cannot be empty",
     "The given name is too long" : "The given name is too long",
     "The given web address is too long" : "The given web address is too long",
+    "The given legal notice address is too long" : "The given legal notice address is too long",
+    "The given privacy policy address is too long" : "The given privacy policy address is too long",
     "The given slogan is too long" : "The given slogan is too long",
     "The given color is invalid" : "The given colour is invalid",
     "The file was uploaded" : "The file was uploaded",
@@ -22,11 +24,14 @@ OC.L10N.register(
     "Unsupported image type" : "Unsupported image type",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
     "Theming" : "Theming",
+    "Legal notice" : "Legal notice",
+    "Privacy policy" : "Privacy policy",
+    "Adjust the Nextcloud theme" : "Adjust the Nextcloud theme",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customise the look and feel of your instance and supported clients. This will be visible for all users.",
     "Name" : "Name",
     "Reset to default" : "Reset to default",
-    "Web address" : "Web address",
-    "Web address https://…" : "Web address https://…",
+    "Web link" : "Web link",
+    "https://…" : "https://…",
     "Slogan" : "Slogan",
     "Color" : "Colour",
     "Logo" : "Logo",
@@ -34,12 +39,13 @@ OC.L10N.register(
     "Login image" : "Login image",
     "Upload new login background" : "Upload new login background",
     "Remove background image" : "Remove background image",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
-    "You are already using a custom theme" : "You are already using a custom theme",
-    "reset to default" : "reset to default",
-    "There is no error, the file uploaded with success" : "There is no error, the file uploaded with success",
-    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
-    "Failed to write file to disk." : "Failed to write file to disk.",
-    "A PHP extension stopped the file upload." : "A PHP extension stopped the file upload."
+    "Advanced options" : "Advanced options",
+    "Legal notice link" : "Legal notice link",
+    "Privacy policy link" : "Privacy policy link",
+    "Header logo" : "Header logo",
+    "Upload new header logo" : "Upload new header logo",
+    "Favicon" : "Favicon",
+    "Upload new favicon" : "Upload new favicon",
+    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color."
 },
 "nplurals=2; plural=(n != 1);");
