@@ -16,6 +16,10 @@ OC.L10N.register(
     "Backup code" : "Varakoodi",
     "Use backup code" : "Käytä varakoodia",
     "Two factor backup codes" : "Kaksivaiheiden tunnistautumisen varakoodit",
-    "Submit" : "Lähetä"
+    "activated" : "aktivoitu",
+    "updated" : "päivitetty",
+    "created" : "luotu",
+    "destroyed" : "tuhottu",
+    "Nextcloud backup codes" : "Nextcloud-varakoodit"
 },
 "nplurals=2; plural=(n != 1);");
