@@ -345,7 +345,7 @@ class Access extends LDAPUtility {
 		}
 		return [];
 	}
-
+	
 	/**
 	 * Set password for an LDAP user identified by a DN
 	 *
@@ -366,7 +366,9 @@ class Access extends LDAPUtility {
 			return false;
 		}
 		try {
-			return @$this->invokeLDAPMethod('modReplace', $cr, $userDN, $password);
+			// try PASSWD extended operation first
+			return @$this->invokeLDAPMethod('exopPasswd', $cr, $userDN, '', $password) ||
+						@$this->invokeLDAPMethod('modReplace', $cr, $userDN, $password);
 		} catch(ConstraintViolationException $e) {
 			throw new HintException('Password change rejected.', \OC::$server->getL10N('user_ldap')->t('Password change rejected. Hint: ').$e->getMessage(), $e->getCode());
 		}
@@ -454,9 +456,11 @@ class Access extends LDAPUtility {
 
 	/**
 	 * returns the internal Nextcloud name for the given LDAP DN of the group, false on DN outside of search DN or failure
+	 *
 	 * @param string $fdn the dn of the group object
 	 * @param string $ldapName optional, the display name of the object
 	 * @return string|false with the name to use in Nextcloud, false on DN outside of search DN
+	 * @throws \Exception
 	 */
 	public function dn2groupname($fdn, $ldapName = null) {
 		//To avoid bypassing the base DN settings under certain circumstances
@@ -511,9 +515,11 @@ class Access extends LDAPUtility {
 
 	/**
 	 * returns the internal Nextcloud name for the given LDAP DN of the user, false on DN outside of search DN or failure
+	 *
 	 * @param string $dn the dn of the user object
 	 * @param string $ldapName optional, the display name of the object
 	 * @return string|false with with the name to use in Nextcloud
+	 * @throws \Exception
 	 */
 	public function dn2username($fdn, $ldapName = null) {
 		//To avoid bypassing the base DN settings under certain circumstances
@@ -646,8 +652,6 @@ class Access extends LDAPUtility {
 			if ($this->ncUserManager instanceof PublicEmitter && $isUser) {
 				$this->cacheUserExists($name);
 				$this->ncUserManager->emit('\OC\User', 'assignedUserId', [$name]);
-			} elseif (!$isUser) {
-				$this->cacheGroupExists($name);
 			}
 			return true;
 		}
@@ -656,10 +660,12 @@ class Access extends LDAPUtility {
 
 	/**
 	 * gives back the user names as they are used ownClod internally
+	 *
 	 * @param array $ldapUsers as returned by fetchList()
 	 * @return array an array with the user names to use in Nextcloud
 	 *
 	 * gives back the user names as they are used ownClod internally
+	 * @throws \Exception
 	 */
 	public function nextcloudUserNames($ldapUsers) {
 		return $this->ldap2NextcloudNames($ldapUsers, true);
@@ -667,10 +673,12 @@ class Access extends LDAPUtility {
 
 	/**
 	 * gives back the group names as they are used ownClod internally
+	 *
 	 * @param array $ldapGroups as returned by fetchList()
 	 * @return array an array with the group names to use in Nextcloud
 	 *
 	 * gives back the group names as they are used ownClod internally
+	 * @throws \Exception
 	 */
 	public function nextcloudGroupNames($ldapGroups) {
 		return $this->ldap2NextcloudNames($ldapGroups, false);
@@ -714,6 +722,8 @@ class Access extends LDAPUtility {
 					$sndName = isset($ldapObject[$sndAttribute][0])
 						? $ldapObject[$sndAttribute][0] : '';
 					$this->cacheUserDisplayName($ncName, $nameByLDAP, $sndName);
+				} else if($nameByLDAP !== null) {
+					$this->cacheGroupDisplayName($ncName, $nameByLDAP);
 				}
 			}
 		}
@@ -751,18 +761,13 @@ class Access extends LDAPUtility {
 		$this->connection->writeToCache('userExists'.$ocName, true);
 	}
 
-	/**
-	 * caches a group as existing
-	 */
-	public function cacheGroupExists(string $gid): void {
-		$this->connection->writeToCache('groupExists'.$gid, true);
-	}
-
 	/**
 	 * caches the user display name
+	 *
 	 * @param string $ocName the internal Nextcloud username
 	 * @param string $displayName the display name
 	 * @param string $displayName2 the second display name
+	 * @throws \Exception
 	 */
 	public function cacheUserDisplayName($ocName, $displayName, $displayName2 = '') {
 		$user = $this->userManager->get($ocName);
@@ -774,6 +779,11 @@ class Access extends LDAPUtility {
 		$this->connection->writeToCache($cacheKeyTrunk.$ocName, $displayName);
 	}
 
+	public function cacheGroupDisplayName(string $ncName, string $displayName): void {
+		$cacheKey = 'group_getDisplayName' . $ncName;
+		$this->connection->writeToCache($cacheKey, $displayName);
+	}
+
 	/**
 	 * creates a unique name for internal Nextcloud use for users. Don't call it directly.
 	 * @param string $name the display name of the object
@@ -887,6 +897,7 @@ class Access extends LDAPUtility {
 	 * @param int $offset
 	 * @param bool $forceApplyAttributes
 	 * @return array
+	 * @throws \Exception
 	 */
 	public function fetchListOfUsers($filter, $attr, $limit = null, $offset = null, $forceApplyAttributes = false) {
 		$ldapRecords = $this->searchUsers($filter, $attr, $limit, $offset);
@@ -947,15 +958,7 @@ class Access extends LDAPUtility {
 	 * @return array
 	 */
 	public function fetchListOfGroups($filter, $attr, $limit = null, $offset = null) {
-		$groupRecords = $this->searchGroups($filter, $attr, $limit, $offset);
-		array_walk($groupRecords, function($record) {
-			$newlyMapped = false;
-			$gid = $this->dn2ocname($record['dn'][0], null, false, $newlyMapped, $record);
-			if(!$newlyMapped && is_string($gid)) {
-				$this->cacheGroupExists($gid);
-			}
-		});
-		return $this->fetchList($groupRecords, $this->manyAttributes($attr));
+		return $this->fetchList($this->searchGroups($filter, $attr, $limit, $offset), $this->manyAttributes($attr));
 	}
 
 	/**
@@ -983,6 +986,7 @@ class Access extends LDAPUtility {
 
 	/**
 	 * executes an LDAP search, optimized for Users
+	 *
 	 * @param string $filter the LDAP filter for the search
 	 * @param string|string[] $attr optional, when a certain attribute shall be filtered out
 	 * @param integer $limit
@@ -990,6 +994,7 @@ class Access extends LDAPUtility {
 	 * @return array with the search result
 	 *
 	 * Executes an LDAP search
+	 * @throws ServerNotAvailableException
 	 */
 	public function searchUsers($filter, $attr = null, $limit = null, $offset = null) {
 		$result = [];
@@ -1005,6 +1010,7 @@ class Access extends LDAPUtility {
 	 * @param int $limit
 	 * @param int $offset
 	 * @return false|int
+	 * @throws ServerNotAvailableException
 	 */
 	public function countUsers($filter, $attr = array('dn'), $limit = null, $offset = null) {
 		$result = false;
@@ -1017,6 +1023,7 @@ class Access extends LDAPUtility {
 
 	/**
 	 * executes an LDAP search, optimized for Groups
+	 *
 	 * @param string $filter the LDAP filter for the search
 	 * @param string|string[] $attr optional, when a certain attribute shall be filtered out
 	 * @param integer $limit
@@ -1024,6 +1031,7 @@ class Access extends LDAPUtility {
 	 * @return array with the search result
 	 *
 	 * Executes an LDAP search
+	 * @throws ServerNotAvailableException
 	 */
 	public function searchGroups($filter, $attr = null, $limit = null, $offset = null) {
 		$result = [];
@@ -1035,11 +1043,13 @@ class Access extends LDAPUtility {
 
 	/**
 	 * returns the number of available groups
+	 *
 	 * @param string $filter the LDAP search filter
 	 * @param string[] $attr optional
 	 * @param int|null $limit
 	 * @param int|null $offset
 	 * @return int|bool
+	 * @throws ServerNotAvailableException
 	 */
 	public function countGroups($filter, $attr = array('dn'), $limit = null, $offset = null) {
 		$result = false;
@@ -1056,6 +1066,7 @@ class Access extends LDAPUtility {
 	 * @param int|null $limit
 	 * @param int|null $offset
 	 * @return int|bool
+	 * @throws ServerNotAvailableException
 	 */
 	public function countObjects($limit = null, $offset = null) {
 		$result = false;
@@ -1159,6 +1170,7 @@ class Access extends LDAPUtility {
 
 	/**
 	 * processes an LDAP paged search operation
+	 *
 	 * @param array $sr the array containing the LDAP search resources
 	 * @param string $filter the LDAP filter for the search
 	 * @param array $base an array containing the LDAP subtree(s) that shall be searched
@@ -1169,6 +1181,7 @@ class Access extends LDAPUtility {
 	 * @param bool $skipHandling required for paged search when cookies to
 	 * prior results need to be gained
 	 * @return bool cookie validity, true if we have more pages, false otherwise.
+	 * @throws ServerNotAvailableException
 	 */
 	private function processPagedSearchStatus($sr, $filter, $base, $iFoundItems, $limit, $offset, $pagedSearchOK, $skipHandling) {
 		$cookie = null;
@@ -1261,6 +1274,7 @@ class Access extends LDAPUtility {
 	/**
 	 * @param array $searchResults
 	 * @return int
+	 * @throws ServerNotAvailableException
 	 */
 	private function countEntriesInSearchResults($searchResults) {
 		$counter = 0;
@@ -1666,6 +1680,7 @@ class Access extends LDAPUtility {
 	 * @param bool $force the detection should be run, even if it is not set to auto
 	 * @param array|null $ldapRecord
 	 * @return bool true on success, false otherwise
+	 * @throws ServerNotAvailableException
 	 */
 	private function detectUuidAttribute($dn, $isUser = true, $force = false, array $ldapRecord = null) {
 		if($isUser) {
@@ -1676,19 +1691,13 @@ class Access extends LDAPUtility {
 			$uuidOverride = $this->connection->ldapExpertUUIDGroupAttr;
 		}
 
-		if(!$force) {
-			if($this->connection->$uuidAttr !== 'auto') {
-				return true;
-			} else if (is_string($uuidOverride) && trim($uuidOverride) !== '') {
-				$this->connection->$uuidAttr = $uuidOverride;
-				return true;
-			}
+		if(($this->connection->$uuidAttr !== 'auto') && !$force) {
+			return true;
+		}
 
-			$attribute = $this->connection->getFromCache($uuidAttr);
-			if(!$attribute === null) {
-				$this->connection->$uuidAttr = $attribute;
-				return true;
-			}
+		if (is_string($uuidOverride) && trim($uuidOverride) !== '' && !$force) {
+			$this->connection->$uuidAttr = $uuidOverride;
+			return true;
 		}
 
 		foreach(self::UUID_ATTRIBUTES as $attribute) {
@@ -1697,29 +1706,27 @@ class Access extends LDAPUtility {
 				if(isset($ldapRecord[$attribute])) {
 					$this->connection->$uuidAttr = $attribute;
 					return true;
+				} else {
+					continue;
 				}
-				continue;
 			}
 
 			$value = $this->readAttribute($dn, $attribute);
 			if(is_array($value) && isset($value[0]) && !empty($value[0])) {
-				\OC::$server->getLogger()->debug(
-					'Setting {attribute} as {subject}',
-					[
-						'app' => 'user_ldap',
-						'attribute' => $attribute,
-						'subject' => $uuidAttr
-					]
+				\OCP\Util::writeLog(
+					'user_ldap',
+					'Setting '.$attribute.' as '.$uuidAttr,
+					ILogger::DEBUG
 				);
 				$this->connection->$uuidAttr = $attribute;
-				$this->connection->writeToCache($uuidAttr, $attribute);
 				return true;
-			} elseif ($value === false) {
-				// record not available
-				return false;
 			}
 		}
-		\OC::$server->getLogger()->debug('Could not autodetect the UUID attribute', ['app' => 'user_ldap']);
+		\OCP\Util::writeLog(
+			'user_ldap',
+			'Could not autodetect the UUID attribute',
+			ILogger::ERROR
+		);
 
 		return false;
 	}
@@ -1729,6 +1736,7 @@ class Access extends LDAPUtility {
 	 * @param bool $isUser
 	 * @param null $ldapRecord
 	 * @return bool|string
+	 * @throws ServerNotAvailableException
 	 */
 	public function getUUID($dn, $isUser = true, $ldapRecord = null) {
 		if($isUser) {
@@ -1834,8 +1842,10 @@ class Access extends LDAPUtility {
 
 	/**
 	 * gets a SID of the domain of the given dn
+	 *
 	 * @param string $dn
 	 * @return string|bool
+	 * @throws ServerNotAvailableException
 	 */
 	public function getSID($dn) {
 		$domainDN = $this->getDomainDNFromDN($dn);
@@ -2004,12 +2014,14 @@ class Access extends LDAPUtility {
 
 	/**
 	 * Prepares a paged search, if possible
+	 *
 	 * @param string $filter the LDAP filter for the search
 	 * @param string[] $bases an array containing the LDAP subtree(s) that shall be searched
 	 * @param string[] $attr optional, when a certain attribute shall be filtered outside
 	 * @param int $limit
 	 * @param int $offset
 	 * @return bool|true
+	 * @throws ServerNotAvailableException
 	 */
 	private function initPagedSearch($filter, $bases, $attr, $limit, $offset) {
 		$pagedSearchOK = false;
