@@ -10,6 +10,8 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Roger Szabo <roger.szabo@web.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
  * @license AGPL-3.0
@@ -48,7 +50,7 @@ abstract class Proxy {
 		$this->ldap = $ldap;
 		$memcache = \OC::$server->getMemCacheFactory();
 		if($memcache->isAvailable()) {
-			$this->cache = $memcache->create();
+			$this->cache = $memcache->createDistributed();
 		}
 	}
 
@@ -65,7 +67,7 @@ abstract class Proxy {
 		static $db;
 		static $coreUserManager;
 		static $coreNotificationManager;
-		if(is_null($fs)) {
+		if($fs === null) {
 			$ocConfig = \OC::$server->getConfig();
 			$fs       = new FilesystemHelper();
 			$log      = new LogWrapper();
@@ -80,7 +82,7 @@ abstract class Proxy {
 			new Manager($ocConfig, $fs, $log, $avatarM, new \OCP\Image(), $db,
 				$coreUserManager, $coreNotificationManager);
 		$connector = new Connection($this->ldap, $configPrefix);
-		$access = new Access($connector, $this->ldap, $userManager, new Helper(\OC::$server->getConfig()));
+		$access = new Access($connector, $this->ldap, $userManager, new Helper($ocConfig), $ocConfig, $coreUserManager);
 		$access->setUserMapper($userMap);
 		$access->setGroupMapper($groupMap);
 		self::$accesses[$configPrefix] = $access;
@@ -158,7 +160,7 @@ abstract class Proxy {
 	 */
 	private function getCacheKey($key) {
 		$prefix = 'LDAP-Proxy-';
-		if(is_null($key)) {
+		if($key === null) {
 			return $prefix;
 		}
 		return $prefix.hash('sha256', $key);
@@ -169,24 +171,17 @@ abstract class Proxy {
 	 * @return mixed|null
 	 */
 	public function getFromCache($key) {
-		if(is_null($this->cache) || !$this->isCached($key)) {
+		if($this->cache === null) {
 			return null;
 		}
+
 		$key = $this->getCacheKey($key);
-
-		return json_decode(base64_decode($this->cache->get($key)));
-	}
-
-	/**
-	 * @param string $key
-	 * @return bool
-	 */
-	public function isCached($key) {
-		if(is_null($this->cache)) {
-			return false;
+		$value = $this->cache->get($key);
+		if ($value === null) {
+			return null;
 		}
-		$key = $this->getCacheKey($key);
-		return $this->cache->hasKey($key);
+
+		return json_decode(base64_decode($value));
 	}
 
 	/**
@@ -194,16 +189,16 @@ abstract class Proxy {
 	 * @param mixed $value
 	 */
 	public function writeToCache($key, $value) {
-		if(is_null($this->cache)) {
+		if($this->cache === null) {
 			return;
 		}
 		$key   = $this->getCacheKey($key);
 		$value = base64_encode(json_encode($value));
-		$this->cache->set($key, $value, '2592000');
+		$this->cache->set($key, $value, 2592000);
 	}
 
 	public function clearCache() {
-		if(is_null($this->cache)) {
+		if($this->cache === null) {
 			return;
 		}
 		$this->cache->clear($this->getCacheKey(null));
