@@ -119,7 +119,7 @@
 				shareWith = 'circle-' + shareIndex;
 			}
 
-			if (sharedBy !== oc_current_user) {
+			if (sharedBy !== OC.getCurrentUser().uid) {
 				var empty = shareWithTitle === '';
 				if (!empty) {
 					shareWithTitle += ' (';
@@ -154,8 +154,8 @@
 				shareId: this.model.get('shares')[shareIndex].id,
 				modSeed: shareWithAvatar || (shareType !== OC.Share.SHARE_TYPE_USER && shareType !== OC.Share.SHARE_TYPE_CIRCLE && shareType !== OC.Share.SHARE_TYPE_ROOM),
 				owner: fileOwnerUid,
-				isShareWithCurrentUser: (shareType === OC.Share.SHARE_TYPE_USER && shareWith === oc_current_user),
-				canUpdateShareSettings: (sharedBy === oc_current_user || fileOwnerUid === oc_current_user),
+				isShareWithCurrentUser: (shareType === OC.Share.SHARE_TYPE_USER && shareWith === OC.getCurrentUser().uid),
+				canUpdateShareSettings: (sharedBy === OC.getCurrentUser().uid || fileOwnerUid === OC.getCurrentUser().uid),
 				isRemoteShare: shareType === OC.Share.SHARE_TYPE_REMOTE,
 				isRemoteGroupShare: shareType === OC.Share.SHARE_TYPE_REMOTE_GROUP,
 				isNoteAvailable: shareType !== OC.Share.SHARE_TYPE_REMOTE && shareType !== OC.Share.SHARE_TYPE_REMOTE_GROUP,
@@ -164,7 +164,7 @@
 				isFileSharedByMail: shareType === OC.Share.SHARE_TYPE_EMAIL && !this.model.isFolder(),
 				isPasswordSet: hasPassword && !sendPasswordByTalk,
 				isPasswordByTalkSet: hasPassword && sendPasswordByTalk,
-				isTalkEnabled: oc_appswebroots['spreed'] !== undefined,
+				isTalkEnabled: OC.appswebroots['spreed'] !== undefined,
 				secureDropMode: !this.model.hasReadPermission(shareIndex),
 				hasExpireDate: this.model.getExpireDate(shareIndex) !== null,
 				shareNote: shareNote,
@@ -720,7 +720,7 @@
 					$editCb.prop('indeterminate', !checked && numberChecked > 0);
 				}
 			} else {
-				if ($('input[name="edit"]', $li).is(':checked')) {
+				if ($element.attr('name') === 'edit' && $element.is(':checked')) {
 					permissions |= OC.PERMISSION_UPDATE;
 				}
 			}
