@@ -3,22 +3,25 @@
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
  * @author Andreas Fischer <bantu@owncloud.com>
- * @author Bartek Przybylski <bart.p.pl@gmail.com>
  * @author Bart Visscher <bartv@thisnet.nl>
+ * @author Bartek Przybylski <bart.p.pl@gmail.com>
  * @author Björn Schießle <bjoern@schiessle.org>
  * @author Byron Marohn <combustible@live.com>
  * @author Christopher Schäpers <kondou@ts.unde.re>
- * @author Georg Ehrke <georg@owncloud.com>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author j-ed <juergen@eisfair.org>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Johannes Willnecker <johannes@willnecker.com>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Olivier Paroz <github@oparoz.com>
  * @author Robin Appelman <robin@icewind.nl>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Thomas Tanghus <thomas@tanghus.net>
+ * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
  * @license AGPL-3.0
  *
@@ -59,22 +62,6 @@ class OC_Image implements \OCP\IImage {
 	/** @var array */
 	private $exif;
 
-	/**
-	 * Get mime type for an image file.
-	 *
-	 * @param string|null $filePath The path to a local image file.
-	 * @return string The mime type if the it could be determined, otherwise an empty string.
-	 */
-	static public function getMimeTypeForFile($filePath) {
-		// exif_imagetype throws "read error!" if file is less than 12 byte
-		if ($filePath !== null && filesize($filePath) > 11) {
-			$imageType = exif_imagetype($filePath);
-		} else {
-			$imageType = false;
-		}
-		return $imageType ? image_type_to_mime_type($imageType) : '';
-	}
-
 	/**
 	 * Constructor.
 	 *
@@ -82,6 +69,7 @@ class OC_Image implements \OCP\IImage {
 	 * an imagecreate* function.
 	 * @param \OCP\ILogger $logger
 	 * @param \OCP\IConfig $config
+	 * @throws \InvalidArgumentException in case the $imageRef parameter is not null
 	 */
 	public function __construct($imageRef = null, \OCP\ILogger $logger = null, \OCP\IConfig $config = null) {
 		$this->logger = $logger;
@@ -98,7 +86,7 @@ class OC_Image implements \OCP\IImage {
 		}
 
 		if ($imageRef !== null) {
-			$this->load($imageRef);
+			throw new \InvalidArgumentException('The first parameter in the constructor is not supported anymore. Please use any of the load* methods of the image object to load an image.');
 		}
 	}
 
@@ -310,6 +298,18 @@ class OC_Image implements \OCP\IImage {
 		return $this->show();
 	}
 
+	/**
+	 * @param resource Returns the image resource in any.
+	 * @throws \InvalidArgumentException in case the supplied resource does not have the type "gd"
+	 */
+	public function setResource($resource) {
+		if (get_resource_type($resource) === 'gd') {
+			$this->resource = $resource;
+			return;
+		}
+		throw new \InvalidArgumentException('Supplied resource is not of type "gd".');
+	}
+
 	/**
 	 * @return resource Returns the image resource in any.
 	 */
@@ -450,7 +450,7 @@ class OC_Image implements \OCP\IImage {
 	 * (I'm open for suggestions on better method name ;)
 	 * Fixes orientation based on EXIF data.
 	 *
-	 * @return bool.
+	 * @return bool
 	 */
 	public function fixOrientation() {
 		$o = $this->getOrientation();
@@ -516,31 +516,6 @@ class OC_Image implements \OCP\IImage {
 		return false;
 	}
 
-	/**
-	 * Loads an image from a local file, a base64 encoded string or a resource created by an imagecreate* function.
-	 *
-	 * @param resource|string $imageRef The path to a local file, a base64 encoded string or a resource created by an imagecreate* function or a file resource (file handle    ).
-	 * @return resource|false An image resource or false on error
-	 */
-	public function load($imageRef) {
-		if (is_resource($imageRef)) {
-			if (get_resource_type($imageRef) === 'gd') {
-				$this->resource = $imageRef;
-				return $this->resource;
-			} elseif (in_array(get_resource_type($imageRef), array('file', 'stream'))) {
-				return $this->loadFromFileHandle($imageRef);
-			}
-		} elseif ($this->loadFromBase64($imageRef) !== false) {
-			return $this->resource;
-		} elseif ($this->loadFromFile($imageRef) !== false) {
-			return $this->resource;
-		} elseif ($this->loadFromData($imageRef) !== false) {
-			return $this->resource;
-		}
-		$this->logger->debug(__METHOD__ . '(): could not load anything. Giving up!', array('app' => 'core'));
-		return false;
-	}
-
 	/**
 	 * Loads an image from an open file handle.
 	 * It is the responsibility of the caller to position the pointer at the correct place and to close the handle again.
@@ -809,16 +784,16 @@ class OC_Image implements \OCP\IImage {
 						$color[1] = (($color[1] & 0xf800) >> 8) * 65536 + (($color[1] & 0x07e0) >> 3) * 256 + (($color[1] & 0x001f) << 3);
 						break;
 					case 8:
-						$color = @unpack('n', $vide . substr($data, $p, 1));
-						$color[1] = (isset($palette[$color[1] + 1])) ? $palette[$color[1] + 1] : $palette[1];
+						$color = @unpack('n', $vide . ($data[$p] ?? ''));
+						$color[1] = isset($palette[$color[1] + 1]) ? $palette[$color[1] + 1] : $palette[1];
 						break;
 					case 4:
-						$color = @unpack('n', $vide . substr($data, floor($p), 1));
+						$color = @unpack('n', $vide . ($data[floor($p)] ?? ''));
 						$color[1] = ($p * 2) % 2 == 0 ? $color[1] >> 4 : $color[1] & 0x0F;
-						$color[1] = (isset($palette[$color[1] + 1])) ? $palette[$color[1] + 1] : $palette[1];
+						$color[1] = isset($palette[$color[1] + 1]) ? $palette[$color[1] + 1] : $palette[1];
 						break;
 					case 1:
-						$color = @unpack('n', $vide . substr($data, floor($p), 1));
+						$color = @unpack('n', $vide . ($data[floor($p)] ?? ''));
 						switch (($p * 8) % 8) {
 							case 0:
 								$color[1] = $color[1] >> 7;
@@ -845,7 +820,7 @@ class OC_Image implements \OCP\IImage {
 								$color[1] = ($color[1] & 0x1);
 								break;
 						}
-						$color[1] = (isset($palette[$color[1] + 1])) ? $palette[$color[1] + 1] : $palette[1];
+						$color[1] = isset($palette[$color[1] + 1]) ? $palette[$color[1] + 1] : $palette[1];
 						break;
 					default:
 						fclose($fh);
@@ -886,7 +861,7 @@ class OC_Image implements \OCP\IImage {
 			$newHeight = $maxSize;
 		}
 
-		$this->preciseResize(round($newWidth), round($newHeight));
+		$this->preciseResize((int)round($newWidth), (int)round($newHeight));
 		return true;
 	}
 
@@ -895,7 +870,7 @@ class OC_Image implements \OCP\IImage {
 	 * @param int $height
 	 * @return bool
 	 */
-	public function preciseResize($width, $height) {
+	public function preciseResize(int $width, int $height): bool {
 		if (!$this->valid()) {
 			$this->logger->error(__METHOD__ . '(): No image loaded', array('app' => 'core'));
 			return false;
@@ -903,10 +878,8 @@ class OC_Image implements \OCP\IImage {
 		$widthOrig = imagesx($this->resource);
 		$heightOrig = imagesy($this->resource);
 		$process = imagecreatetruecolor($width, $height);
-
-		if ($process == false) {
+		if ($process === false) {
 			$this->logger->error(__METHOD__ . '(): Error creating true color image', array('app' => 'core'));
-			imagedestroy($process);
 			return false;
 		}
 
@@ -917,8 +890,8 @@ class OC_Image implements \OCP\IImage {
 			imagesavealpha($process, true);
 		}
 
-		imagecopyresampled($process, $this->resource, 0, 0, 0, 0, $width, $height, $widthOrig, $heightOrig);
-		if ($process == false) {
+		$res = imagecopyresampled($process, $this->resource, 0, 0, 0, 0, $width, $height, $widthOrig, $heightOrig);
+		if ($res === false) {
 			$this->logger->error(__METHOD__ . '(): Error re-sampling process image', array('app' => 'core'));
 			imagedestroy($process);
 			return false;
@@ -995,7 +968,7 @@ class OC_Image implements \OCP\IImage {
 	 * @param int $h Height
 	 * @return bool for success or failure
 	 */
-	public function crop($x, $y, $w, $h) {
+	public function crop(int $x, int $y, int $w, int $h): bool {
 		if (!$this->valid()) {
 			$this->logger->error(__METHOD__ . '(): No image loaded', array('app' => 'core'));
 			return false;
@@ -1046,7 +1019,7 @@ class OC_Image implements \OCP\IImage {
 		$newWidth = min($maxWidth, $ratio * $maxHeight);
 		$newHeight = min($maxHeight, $maxWidth / $ratio);
 
-		$this->preciseResize(round($newWidth), round($newHeight));
+		$this->preciseResize((int)round($newWidth), (int)round($newHeight));
 		return true;
 	}
 
