@@ -1,8 +1,12 @@
 <?php
 /**
- *
  * @copyright Copyright (c) 2016, Roger Szabo (roger.szabo@web.de)
  *
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Roger Szabo <roger.szabo@web.de>
+ * @author root <root@localhost.localdomain>
+ * @author Vinicius Cubas Brand <vinicius@eita.org.br>
+ *
  * @license GNU AGPL version 3 or any later version
  *
  * This program is free software: you can redistribute it and/or modify
@@ -36,7 +40,15 @@ interface ILDAPProvider {
 	 * @since 11.0.0
 	 */
 	public function getUserDN($uid);
-	
+
+	/**
+	 * Translate a group id to LDAP DN.
+	 * @param string $gid group id
+	 * @return string
+	 * @since 13.0.0
+	 */
+	public function getGroupDN($gid);
+
 	/**
 	 * Translate a LDAP DN to an internal user name.
 	 * @param string $dn LDAP DN
@@ -69,6 +81,14 @@ interface ILDAPProvider {
 	 * @since 11.0.0
 	 */
 	public function getLDAPConnection($uid);
+
+	/**
+	 * Return a new LDAP connection resource for the specified group.
+	 * @param string $gid group id
+	 * @return resource of the LDAP connection
+	 * @since 13.0.0
+	 */
+	public function getGroupLDAPConnection($gid);
 	
 	/**
 	 * Get the LDAP base for users.
@@ -102,4 +122,39 @@ interface ILDAPProvider {
 	 * @since 11.0.0
 	 */
 	public function clearCache($uid);
+
+	/**
+	 * Clear the cache if a cache is used, otherwise do nothing.
+	 * @param string $gid group id
+	 * @since 13.0.0
+	 */
+	public function clearGroupCache($gid);
+
+	/**
+	 * Get the LDAP attribute name for the user's display name
+	 * @param string $uid user id
+	 * @return string the display name field
+	 * @throws \Exception if user id was not found in LDAP
+	 * @since 12.0.0
+	 */
+	public function getLDAPDisplayNameField($uid);
+
+	/**
+	 * Get the LDAP attribute name for the email
+	 * @param string $uid user id
+	 * @return string the email field
+	 * @throws \Exception if user id was not found in LDAP
+	 * @since 12.0.0
+	 */
+	public function getLDAPEmailField($uid);
+
+	/**
+	 * Get the LDAP attribute name for the type of association betweeen users and groups
+	 * @param string $gid group id
+	 * @return string the configuration, one of: 'memberUid', 'uniqueMember', 'member', 'gidNumber', ''
+	 * @throws \Exception if group id was not found in LDAP
+	 * @since 13.0.0
+	 */
+	public function getLDAPGroupMemberAssoc($gid);
+
 }
